summaryrefslogtreecommitdiff
path: root/vcl/source/uitest/uiobject.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'vcl/source/uitest/uiobject.cxx')
-rw-r--r--vcl/source/uitest/uiobject.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/vcl/source/uitest/uiobject.cxx b/vcl/source/uitest/uiobject.cxx
index 407289dfd8d2..fee55d88dc11 100644
--- a/vcl/source/uitest/uiobject.cxx
+++ b/vcl/source/uitest/uiobject.cxx
@@ -74,8 +74,8 @@ namespace {
bool isDialogWindow(vcl::Window* pWindow)
{
WindowType nType = pWindow->GetType();
- // DIALOG to FONTDIALOG
- if (nType >= WindowType::DIALOG && nType <= WindowType::FONTDIALOG)
+ // DIALOG to MODALDIALOG
+ if (nType >= WindowType::DIALOG && nType <= WindowType::MODALDIALOG)
return true;
// MESSBOX, INFOBOX, WARNINGBOX, ERRORBOX, QUERYBOX